@@ -1,6 +1,6 @@
-linux-6.6.122-sparky-lts66 for Debian
+linux-6.6.125-sparky-lts66 for Debian
 ------------------------------------
 
 <Possible notes regarding this package - if none, delete this file.>
 
- -- pavroo <pavroo@onet.eu>  Fri, 30 Jan 2026 17:37:14 +0100
+ -- pavroo <pavroo@onet.eu>  Mon, 16 Feb 2026 12:11:43 +0100
