@@ -1,4 +1,4 @@
-linux-6.6.122-sparky-lts66 for Debian
+linux-6.6.125-sparky-lts66 for Debian
 ------------------------------------
 
 <This file describes information about the source package, see Debian policy
@@ -6,4 +6,4 @@ manual section 4.14. You WILL either need to modify or delete this file.>
 
 
 
- -- pavroo <pavroo@onet.eu>  Fri, 30 Jan 2026 17:37:14 +0100
+ -- pavroo <pavroo@onet.eu>  Mon, 16 Feb 2026 12:11:43 +0100
